#
# spec file for package cfengine-masterfiles
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cfengine-masterfiles

# Yes, its not FHS conformant but in sync with cfengine documentation
# reported upstream as https://cfengine.com/dev/issues/1896
%define         basedir   /var/cfengine
%define         workdir   %{basedir}

Summary:        CFEngine promises master files
License:        MIT and LGPL-3.0+
Group:          Productivity/Networking/System
Version:        3.10.1
Release:        lp150.1.3
%define srcname masterfiles
Url:            http://www.cfengine.org/
Source:         https://github.com/cfengine/masterfiles/archive/%{version}.tar.gz#/%{srcname}-%{version}.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

Requires:       cfengine
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cfengine
BuildRequires:  findutils

# wtf? SLE_11 does not honor rpmlintrc
Source1:        %{name}-rpmlintrc
%if 0%{?suse_version} <= 1130
BuildRequires:  -post-build-checks
%endif
%if 0%{?fedora_version} == 20 || 0%{?rhel_version} >= 700
BuildRequires:  perl-Exporter
%endif

%description
Masterfiles are the pristine version of the CFEngine promises. These
will be available in /var/cfengine/masterfiles and are copied to
/var/cfengine/inputs by CFEngine.

%prep
%setup -q -n %{srcname}-%{version}

%build
# EXPLICIT_VERSION must be set in the environment else creation of
# configure will fail
export EXPLICIT_VERSION="%{version}" 
autoreconf -fiv
%configure --prefix=%{basedir}

%install

%{__install} -d %{buildroot}/%{basedir}/masterfiles
%{__make} "DESTDIR=%{buildroot}" install

%files
%defattr(-,root,root)
%doc LICENSE README.md CONTRIBUTING.md
%dir %{basedir}
%dir %{basedir}/masterfiles
%{basedir}/masterfiles/*
%dir %{basedir}/modules/packages
%{basedir}/modules/packages/*

%changelog
* Fri Mar 31 2017 kkaempf@suse.com
- Update to 3.10.1
  See https://github.com/cfengine/core/blob/3.10.1/ChangeLog
  for full ChangeLog
* Wed Nov 16 2016 kkaempf@suse.com
- Update to 3.10.0 (beta1) - LTS until Dec 2019
  See https://github.com/cfengine/core/blob/3.10.0b1/ChangeLog
  for full ChangeLog
* Fri Aug  5 2016 kkaempf@suse.com
- Update to 3.9.1
  See cfengine package for changelog
* Thu Jul 28 2016 mpluskal@suse.com
- Use url for source
- Simplify some variables in spec file
- Use macro for configure
* Wed Jun 15 2016 kkaempf@suse.com
- Update to 3.9.0
  See cfengine package for changelog
* Mon Dec  7 2015 kkaempf@suse.com
- Update to 3.8.0
  See cfengine package for changelog
* Wed Sep  9 2015 kkaempf@suse.com
- Update to 3.7.1 (LTS release)
  * Augmenting inputs from the augments_file (Redmine #7420)
* Thu Jul 30 2015 kkaempf@suse.com
- Update to 3.7.0
  Added
  * Support for user specified overring of framework defaults without
    modifying policy supplied by the framework itself (see example_def.json)
  * Support for def.json class augmentation in update policy
  * Run vacuum operation on postgresql every night as a part of maintenance.
  * Add measure_promise_time action body to lib (3.5, 3.6, 3.7, 3.8)
  * New negative class guard cfengine_internal_disable_agent_email so that
    agent email can be easily disabled by augmenting def.json
  Changed
  * Relocate def.cf to controls/VER/
  * Relocate update_def to controls/VER
  * Relocate all controls to controls/VER
  * Only load cf_hub and reports.cf on CFEngine Enterprise installs
  * Relocate acls related to report collection from bundle server
    access_rules to controls/VER/reports.cf into bundle server
    report_access_rules
  * Re-organize cfe_internal splitting core from enterprise specific
    policies and loading the appropriate inputs only when necessary
  * Moved update directory into cfe_internal as it is not generally
    intended to be modified
  * services/autorun.cf moved to lib/VER/ as it is not generally intended
    to be modified
  * To improve predictibility autorun bundles are activated in
    lexicographical order
  * Relocate services/file_change.cf to cfe_internal/enterprise. This
    policy is most useful for a good OOTB experience with CFEngine
    Enterprise Mission Portal.
  * Relocate service_catalogue from promsies.cf to services/main.cf. It is
    intended to be a user entry. This name change correlates with the main
    bundle being activated by default if there is no bundlesequence
    specified.
  * Reduce benchmarks sample history to 1 day.
  * Update policy no longer generates a keypair if one is not found.
    (Redmine: #7167)
  * Relocate cfe_internal_postgresql_maintenance bundle to lib/VER/
  * Set postgresql_monitoring_maintenance only for versions 3.6.0 and 3.6.1
  * Move hub specific bundles from lib/VER/cfe_internal.cf into
    lib/VER/cfe_internal_hub.cf and load them only if policy_server policy
    if set.
  * Re-organize lib/VER/stdlib.cf from lists into classic array for use
    with getvalues
  * inform_mode classes changed to DEBUG|DEBUG_$(this.bundle):: (Redmine:
    [#7191])
  * Enabled limit_robot_agents in order to work around multiple cf-execd
    processes after upgrade. (Redmine #7185)
  Removed
  * Diff reporting on /etc/shadow (Enterprise)
  * Update policy from promise.cf inputs. There is no reason to include
    the update policy into promsies.cf, update.cf is the entry for the
    update policy
  * _not_repaired outcome from classes_generic and scoped_classes generic
    (Redmine: # 7022)
  Fixed
  * standard_services now restarts the service if it was not already
    running when using service_policy => restart with chkconfig (Redmine
    [#7258])
  * Fix process_result logic to match the purpose of body process_select
    days_older_than (Redmine #3009)
- drop patch, upstream
  build-without-core.patch
* Thu Jun 18 2015 kkaempf@suse.com
- fix Fedora/RHEL builds - add perl-Exporter to BuildRequires
* Fri Mar 13 2015 kkaempf@suse.com
- Update to 3.6.5
  RHEL7 support, systemd support, bugfixes.
* Wed Jan 28 2015 kkaempf@suse.com
- Update to 3.6.4
  Bugfix release
* Thu Oct  9 2014 kkaempf@suse.com
- Update to 3.6.2
  Bugfix release
* Tue Sep 16 2014 kkaempf@suse.com
- Update to 3.6.2-build5 pre-release
* Thu Aug  7 2014 kkaempf@suse.com
- fix build for SLE 11
  add cfengine-masterfiles-rpmlintrc
* Wed Jul 30 2014 kkaempf@suse.com
- Update to 3.6.1
  * Bugfix release
  * Fix systemctl path for service promises
- add build-without-core.patch, no 'core' source available
- drop masterfiles-3.6.0.patch, upstream
* Tue Jul  1 2014 kkaempf@suse.com
- make masterfiles accessible to non-root users.
  add masterfiles-3.6.0.patch
* Wed Jun 18 2014 kkaempf@suse.com
- Update to 3.6.0 final
  Bugfixes
* Fri May 30 2014 kkaempf@suse.com
- Update to 3.6.0-rc2
  Bugfix release
- drop 0001-Fix-SUSE-suse-spelling.patch,
  and 0002-More-SuSE-suse-renames.patch, (included upstream)
  drop 0001-Use-systemctl-to-start-stop-cfengine-processes-if-sy.patch
  (reverted)
* Fri May  2 2014 kkaempf@suse.com
- start/stop cf-* processes via systemctl
  Add 0001-Use-systemctl-to-start-stop-cfengine-processes-if-sy.patch
* Fri Apr 11 2014 kkaempf@suse.com
- change license from 'MIT' to 'MIT and LGPL-3.0+'
- add two patches to fix 'SuSE' spelling
  0001-Fix-SUSE-suse-spelling.patch
  0002-More-SuSE-suse-renames.patch
* Fri Apr 11 2014 kkaempf@suse.com
- Update to 3.6rc
  Bugfix release
* Thu Apr 10 2014 kkaempf@suse.com
- add inventory/linux.cf to parse /etc/os-release
- check /proc/1/cmdline and set 'systemd' if this is the init process.
* Tue Mar 18 2014 kkaempf@suse.com
- New package, version 3.6.0b2
